from setuptools import setup

setup(
    name='leakz',
    version='1.0',
    packages=['leakz'],
    url='https://github.com/thehappydinoa/leakz',
    license='MIT',
    author='thehappydinoa',
    author_email='thehappydinoa@gmail.com',
    description='Python API wrapper for lea.kz',

    classifiers=[
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 5 - Production/Stable',

        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        'License :: OSI Approved :: MIT License',

        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ]
)


import json

import requests


def api_request(path: str, base_url: str = "https://lea.kz") -> dict:
    try:
        return requests.get(base_url + path).json()
    except (requests.exceptions.RequestException, json.decoder.JSONDecodeError):
        return dict()


def leaked_mail(email_address: str) -> list:
    response = api_request("/api/mail/" + email_address).get("leaked")
    if response:
        return response.split(', ')
    return list()


def password_from_hash(hash: str) -> str:
    return api_request("/api/hash/" + hash).get("password")


def hash_from_password(password) -> dict:
    return api_request("/api/password/" + password)